==> haskell-ghc-source-gen-0.4.6.0-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-source-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-source-gen
version:              0.4.6.0
visibility:           public
id:                   ghc-source-gen-0.4.6.0-6BHbvXhZeI66FxC8dpxTQc
key:                  ghc-source-gen-0.4.6.0-6BHbvXhZeI66FxC8dpxTQc
license:              BSD-3-Clause
copyright:            Google LLC
maintainer:           judahjacobson@google.com
author:               Judah Jacobson
homepage:             https://github.com/google/ghc-source-gen#readme
synopsis:             Constructs Haskell syntax trees for the GHC API.
description:
    @ghc-source-gen@ is a library for generating Haskell source code.
    It uses the <https://hackage.haskell.org/package/ghc ghc> library
    to support recent language extensions, and provides a simple, consistent
    interface across several major versions of GHC.

    To get started, take a look at the "GHC.SourceGen" module.

    For more information, please see the <https://github.com/google/ghc-source-gen README>.

category:             Development
abi:                  038789f4e9899269704640663f962fdf
exposed:              True
exposed-modules:
    GHC.SourceGen GHC.SourceGen.Binds GHC.SourceGen.Decl
    GHC.SourceGen.Expr GHC.SourceGen.Lit GHC.SourceGen.Module
    GHC.SourceGen.Name GHC.SourceGen.Overloaded GHC.SourceGen.Pat
    GHC.SourceGen.Pat.Internal GHC.SourceGen.Pretty GHC.SourceGen.Type

hidden-modules:
    GHC.SourceGen.Binds.Internal GHC.SourceGen.Expr.Internal
    GHC.SourceGen.Lit.Internal GHC.SourceGen.Name.Internal
    GHC.SourceGen.Syntax.Internal GHC.SourceGen.Type.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-source-gen-0.4.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-source-gen-0.4.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-source-gen-0.4.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-source-gen
hs-libraries:         HSghc-source-gen-0.4.6.0-6BHbvXhZeI66FxC8dpxTQc
depends:              base-4.17.2.1 ghc-9.4.8
haddock-interfaces:
    /usr/share/doc/haskell-ghc-source-gen/html/ghc-source-gen.haddock

haddock-html:         /usr/share/doc/haskell-ghc-source-gen/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-source-gen-0.4.6.0-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-source-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-source-gen
version:              0.4.6.0
visibility:           public
id:                   ghc-source-gen-0.4.6.0-Jc0v8R6SZvY7nDhgGEZEj5
key:                  ghc-source-gen-0.4.6.0-Jc0v8R6SZvY7nDhgGEZEj5
license:              BSD-3-Clause
copyright:            Google LLC
maintainer:           judahjacobson@google.com
author:               Judah Jacobson
homepage:             https://github.com/google/ghc-source-gen#readme
synopsis:             Constructs Haskell syntax trees for the GHC API.
description:
    @ghc-source-gen@ is a library for generating Haskell source code.
    It uses the <https://hackage.haskell.org/package/ghc ghc> library
    to support recent language extensions, and provides a simple, consistent
    interface across several major versions of GHC.

    To get started, take a look at the "GHC.SourceGen" module.

    For more information, please see the <https://github.com/google/ghc-source-gen README>.

category:             Development
abi:                  9502f3d2ab24aecee4e80f2560fd5762
exposed:              True
exposed-modules:
    GHC.SourceGen GHC.SourceGen.Binds GHC.SourceGen.Decl
    GHC.SourceGen.Expr GHC.SourceGen.Lit GHC.SourceGen.Module
    GHC.SourceGen.Name GHC.SourceGen.Overloaded GHC.SourceGen.Pat
    GHC.SourceGen.Pat.Internal GHC.SourceGen.Pretty GHC.SourceGen.Type

hidden-modules:
    GHC.SourceGen.Binds.Internal GHC.SourceGen.Expr.Internal
    GHC.SourceGen.Lit.Internal GHC.SourceGen.Name.Internal
    GHC.SourceGen.Syntax.Internal GHC.SourceGen.Type.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-source-gen-0.4.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-source-gen-0.4.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-source-gen-0.4.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-source-gen
hs-libraries:         HSghc-source-gen-0.4.6.0-Jc0v8R6SZvY7nDhgGEZEj5
depends:              base-4.17.2.1 ghc-9.4.8
haddock-interfaces:
    /usr/share/doc/haskell-ghc-source-gen/html/ghc-source-gen.haddock

haddock-html:         /usr/share/doc/haskell-ghc-source-gen/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
